|TRAVIS|

sage-analysis
=============

Package to ingest, analyse, and plot all the SAGE data products

.. |TRAVIS| image::
  https://img.shields.io/travis/com/jacobseiler/sage-analysis/master.svg?logo=travis&logoColor=white&label=Travis%20CI
  :alt: Travis Badge
  :target: https://travis-ci.com/jacobseiler/sage-analysis
